<?php

namespace Provider\Package\Workflow;

use Provider\Package\Models\User;
use Validator;

class UserValidator
{

    /**
     * Determine if the given user is valid for complete status.
     *
     * @param User $user
     *
     * @return bool / Validator
     */
    public function complete(User $user)
    {
        return Validator::make($user->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given user is valid for verify status.
     *
     * @param User $user
     *
     * @return bool / Validator
     */
    public function verify(User $user)
    {
        return Validator::make($user->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given user is valid for approve status.
     *
     * @param User $user
     *
     * @return bool / Validator
     */
    public function approve(User $user)
    {
        return Validator::make($user->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given user is valid for publish status.
     *
     * @param User $user
     *
     * @return bool / Validator
     */
    public function publish(User $user)
    {
        return Validator::make($user->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given user is valid for archive status.
     *
     * @param User $user
     *
     * @return bool / Validator
     */
    public function archive(User $user)
    {
        return Validator::make($user->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given user is valid for unpublish status.
     *
     * @param User $user
     *
     * @return bool / Validator
     */
    public function unpublish(User $user)
    {
        return Validator::make($user->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
